﻿#if UNITY_IOS
using System.IO;
using UnityEditor;
using UnityEditor.Callbacks;
using UnityEditor.Build;
using UnityEditor.Build.Reporting;
using UnityEngine;
using Amanotes.TripleSDK.Firebase;
using System.Text.RegularExpressions;
using UnityEditor.iOS.Xcode;

namespace Amanotes.TripleSDK.Editor
{
    [InitializeOnLoad]    
    public class AmaAuthBuildProcessor : IPreprocessBuildWithReport
    {
        public static AuthConfiguration config;
        public int callbackOrder { get { return 0; } }

        public void OnPreprocessBuild(BuildReport report)
        {
            config = Resources.Load<AuthConfiguration>("GoogleSignIn");

            //Change client ID in Google Sign In plugin
            string ggFile = Path.GetFullPath("Packages/com.amanotes.sdk.googlesignin/Runtime/Plugins/iOS/GoogleSignInAppController.mm");
            if (File.Exists(ggFile))
            {
                string text = File.ReadAllText(ggFile);
                text = Regex.Replace(text, "\\*clientId =.*", $"*clientId = @\"{config.iOSClientID}\";");
                File.WriteAllText(ggFile, text);
                Debug.Log("[AmaAuth] Change clientID");
            }

            Debug.Log("[AmaAuth] Finish preprocessing.");
        }

        [PostProcessBuild(1)]
        public static void OnPostProcessBuild(BuildTarget buildTarget, string pathToBuiltProject)
        {
            //Add iOS URL scheme
            string plistPath = pathToBuiltProject + "/Info.plist";
            PlistDocument plist = new PlistDocument();
            plist.ReadFromFile(plistPath);

            //Get root
            PlistElementDict rootDict = plist.root;

            if (rootDict["CFBundleURLTypes"] == null)
                rootDict.CreateArray("CFBundleURLTypes");

            //Add new URL types
            PlistElementDict ggClientID = rootDict.values["CFBundleURLTypes"].AsArray().AddDict();
            ggClientID.SetString("CFBundleTypeRole", "Editor");
            ggClientID.SetString("CFBundleURLName", "google-sign-in");
            PlistElementArray array = ggClientID.CreateArray("CFBundleURLSchemes");
            array.AddString(config.iOSURLScheme);

            plist.WriteToFile(plistPath);

            Debug.Log("[AmaAuth] Finish postprocessing.");
        }
    }

}
#endif