﻿using System.IO;
using UnityEditor;
using UnityEngine;
using Amanotes.TripleSDK.Core;

namespace Amanotes.TripleSDK.Firebase.Editor
{
    [InitializeOnLoad]
    [System.Diagnostics.MonitoringDescription("com.amanotes.sdk.firebase.auth")]
    public class AmaAuthEditor : EditorWindow
    {
        private const string ASSET_PATH = "Assets/Resources/GoogleSignIn.asset";
        [UnityEditor.Callbacks.DidReloadScripts]
        static AmaAuthEditor()
        {
            CreateDefaultConfigIfNeed();
        }

        private static void CreateDefaultConfigIfNeed()
        {
            var filePath = "Resources/GoogleSignIn.asset";
            var file = Path.Combine(Application.dataPath, filePath);
            if (!File.Exists(file))
            {
                var config = ScriptableObject.CreateInstance<AuthConfiguration>();

                AssetDatabase.CreateAsset(config, ASSET_PATH);
                AssetDatabase.SaveAssets();
                AssetDatabase.Refresh();
            }
        }


        // this method will be invoked from SDK Manager
        public static void CustomRender()
        {
            GUIHelper.DrawTitle("User Login System");
            GUILayout.Space(10);

            GUILayout.BeginHorizontal();
            GUIHelper.DrawHeader("Google Sign In");
            if (GUILayout.Button("Edit", GUILayout.Width(100)))
            {
                Selection.activeObject = AssetDatabase.LoadMainAssetAtPath(ASSET_PATH);
            }
            GUILayout.EndHorizontal();
            GUILayout.Space(5);
            GUIHelper.GUILine();
        }

        public static void OnRemove()
        {
            //Remove example
            var authExample = Path.Combine(Application.dataPath, "AmaSDK/LoginSample");
            if (Directory.Exists(authExample))
            {
                Directory.Delete(authExample, true);
                Debug.Log("[Auth] Delete login sample");
            }
            //Not remove Facebook SDK and Google Sign In
        }

        public static void Render(int target)
        {
            GUILayout.Space(10);
            GUILayout.BeginHorizontal();
            GUIHelper.DrawHeader("User Login Samples");
            if (GUILayout.Button("Import", GUILayout.Width(100)))
            {
                // My sample directory
                var cachePackageDir = Path.Combine(Directory.GetParent(Application.dataPath).FullName, "Library/PackageCache");
                var dirs = Directory.GetDirectories(cachePackageDir, "com.amanotes.sdk.firebase.auth@*");

                var packageDir = dirs[0];
                var sampleFile = Path.Combine(packageDir, "Samples~/Samples", "LoginSample.unitypackage");

                if (!File.Exists(sampleFile))
                {
                    EditorUtility.DisplayDialog("Error", "Sample not found", "OK");
                    return;
                }

                // import the package
                AssetDatabase.ImportPackage(sampleFile, true);

            }
            GUILayout.EndHorizontal();
            GUILayout.Space(5);
            GUIHelper.GUILine();
        }
    }

}
