using System.Collections.Generic;
using UnityEngine;
using Amanotes.TripleSDK.Firebase;

namespace Amanotes.TripleSDK.Core.Analytics
{
    [InjectService]
    [UnityEngine.Scripting.Preserve]
    public class ULSAnalytics : IULSAnalytics
    {        
        const string EVENT_LOGIN = "login";
        const string EVENT_SOCIAL_SHARE = "social_share";
        const string EVENT_LOGIN_PASSPORT = "login_passport";
        const string EVENT_USER_PROFILE = "user_profile";
        const string EVENT_FOLLOW = "follow";
        const string EVENT_UNFOLLOW = "unfollow";
        const string EVENT_SOCIAL_PROFILE = "social_profile";
        const string EVENT_GAME_LEADERBOARD = "game_leaderboard";
        const string EVENT_LOGOUT = "logout";

        const string amaSession = "ama_open_session";

        protected virtual void LogEvent(string eventName, Dictionary<string, object> paramaters)
        {
            FirebaseAuthService.Instance.Countly?.LogEvent(eventName, paramaters);
            Bootstrap.GetService<IAnalytics>().LogEvent(eventName, paramaters);
        }

        public ULSContext Context => Bootstrap.GetService<ULSContext>();

        public void LogEventLogin()
        {
            var parameters = new Dictionary<string, object> {
                {"bundle_id", Application.identifier},
                {"login_platform", Context.LoginPlatform},
                {"screen", Context.Screen},
                {"session_id", GetSessionId()},
                {"ama_id", Context.AmaId},
                {"result", Context.Result}                
            };
            LogEvent(EVENT_LOGIN, parameters);
        }

        public void LogEventSocialShare()
        {
            var parameters = new Dictionary<string, object> {
                {"bundle_id", Application.identifier},
                {"screen", Context.Screen},
                {"social_platform", Context.SocialPlatform},
                {"result", Context.Result}                
            };
            LogEvent(EVENT_SOCIAL_SHARE, parameters);
        }

        public void LogEventLoginPassport()
        {
            var parameters = new Dictionary<string, object> {
                {"bundle_id", Application.identifier},
                {"passport_platform", Context.PassportPlatform},
                {"session_id", GetSessionId()},
                {"result", Context.Result}
            };
            LogEvent(EVENT_LOGIN_PASSPORT, parameters);
        }

        public void LogEventUserProfile()
        {
            var parameters = new Dictionary<string, object> {
                {"bundle_id", Application.identifier},
                {"screen", Context.Screen},
                {"ama_id", Context.AmaId}
            };
            LogEvent(EVENT_USER_PROFILE, parameters);
        }

        public void LogEventFollow()
        {
            var parameters = new Dictionary<string, object> {
                {"bundle_id", Application.identifier},
                {"screen", Context.Screen},
                {"session_id", GetSessionId()},
                {"ama_id", Context.AmaId},
                {"result", Context.Result}
            };
            LogEvent(EVENT_FOLLOW, parameters);
        }

        public void LogEventUnfollow()
        {
            var parameters = new Dictionary<string, object> {
                {"bundle_id", Application.identifier},
                {"screen", Context.Screen},
                {"session_id", GetSessionId()},
                {"ama_id", Context.AmaId},
                {"result", Context.Result}
            };
            LogEvent(EVENT_UNFOLLOW, parameters);
        }

        public void LogEventSocialProfile()
        {
            var parameters = new Dictionary<string, object> {
                {"bundle_id", Application.identifier},
                {"session_id", GetSessionId()},
                {"ama_id", Context.AmaId},
                {"result", Context.Result}
            };
            LogEvent(EVENT_SOCIAL_PROFILE, parameters);
        }

        public void LogEventGameLeaderboard()
        {
            var parameters = new Dictionary<string, object> {
                {"bundle_id", Application.identifier},
                {"session_id", GetSessionId()},
                {"song_id", Context.SongId},
                {"rank", Context.Rank},
                {"geo", Context.Geo}
            };
            LogEvent(EVENT_GAME_LEADERBOARD, parameters);
        }

        public void LogEventLogout()
        {
            var parameters = new Dictionary<string, object> {
                {"bundle_id", Application.identifier},
                {"session_id", GetSessionId()},
                {"ama_id", Context.AmaId},
                {"result", Context.Result}
            };
            LogEvent(EVENT_LOGOUT, parameters);
        }

        string GetSessionId()
        {
            return !string.IsNullOrEmpty(Context.SessionId) ? Context.SessionId : PlayerPrefs.GetInt(amaSession, 0).ToString();
        }
    }
}